Index: src/x64/lithium-codegen-x64.cc |
diff --git a/src/x64/lithium-codegen-x64.cc b/src/x64/lithium-codegen-x64.cc |
index a2ff91b3351c9bd95291f52aafe9cf821fc9eac1..65dce516465728fd14d607b4710ff91dfd26f805 100644 |
--- a/src/x64/lithium-codegen-x64.cc |
+++ b/src/x64/lithium-codegen-x64.cc |
@@ -200,7 +200,7 @@ bool LCodeGen::GeneratePrologue() { |
need_write_barrier = false; |
} else { |
__ Push(rdi); |
- __ CallRuntime(Runtime::kHiddenNewFunctionContext, 1); |
+ __ CallRuntime(Runtime::kNewFunctionContext, 1); |
} |
RecordSafepoint(Safepoint::kNoLazyDeopt); |
// Context is returned in rax. It replaces the context passed to us. |
@@ -3474,7 +3474,7 @@ void LCodeGen::DoDeclareGlobals(LDeclareGlobals* instr) { |
__ Push(rsi); // The context is the first argument. |
__ Push(instr->hydrogen()->pairs()); |
__ Push(Smi::FromInt(instr->hydrogen()->flags())); |
- CallRuntime(Runtime::kHiddenDeclareGlobals, 3, instr); |
+ CallRuntime(Runtime::kDeclareGlobals, 3, instr); |
} |
@@ -3606,7 +3606,7 @@ void LCodeGen::DoDeferredMathAbsTaggedHeapNumber(LMathAbs* instr) { |
// Slow case: Call the runtime system to do the number allocation. |
__ bind(&slow); |
CallRuntimeFromDeferred( |
- Runtime::kHiddenAllocateHeapNumber, 0, instr, instr->context()); |
+ Runtime::kAllocateHeapNumber, 0, instr, instr->context()); |
// Set the pointer to the new heap number in tmp. |
if (!tmp.is(rax)) __ movp(tmp, rax); |
// Restore input_reg after call to runtime. |
@@ -4552,7 +4552,7 @@ void LCodeGen::DoDeferredStringCharCodeAt(LStringCharCodeAt* instr) { |
__ Push(index); |
} |
CallRuntimeFromDeferred( |
- Runtime::kHiddenStringCharCodeAt, 2, instr, instr->context()); |
+ Runtime::kStringCharCodeAtRT, 2, instr, instr->context()); |
__ AssertSmi(rax); |
__ SmiToInteger32(rax, rax); |
__ StoreToSafepointRegisterSlot(result, rax); |
@@ -4731,11 +4731,11 @@ void LCodeGen::DoDeferredNumberTagIU(LInstruction* instr, |
// NumberTagIU uses the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
// They only call Runtime::kHiddenAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
__ movp(rsi, Operand(rbp, StandardFrameConstants::kContextOffset)); |
- __ CallRuntimeSaveDoubles(Runtime::kHiddenAllocateHeapNumber); |
+ __ CallRuntimeSaveDoubles(Runtime::kAllocateHeapNumber); |
RecordSafepointWithRegisters( |
instr->pointer_map(), 0, Safepoint::kNoLazyDeopt); |
__ StoreToSafepointRegisterSlot(reg, rax); |
@@ -4787,11 +4787,11 @@ void LCodeGen::DoDeferredNumberTagD(LNumberTagD* instr) { |
PushSafepointRegistersScope scope(this); |
// NumberTagD uses the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
// They only call Runtime::kHiddenAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
__ movp(rsi, Operand(rbp, StandardFrameConstants::kContextOffset)); |
- __ CallRuntimeSaveDoubles(Runtime::kHiddenAllocateHeapNumber); |
+ __ CallRuntimeSaveDoubles(Runtime::kAllocateHeapNumber); |
RecordSafepointWithRegisters( |
instr->pointer_map(), 0, Safepoint::kNoLazyDeopt); |
__ movp(kScratchRegister, rax); |
@@ -5349,7 +5349,7 @@ void LCodeGen::DoDeferredAllocate(LAllocate* instr) { |
__ Push(Smi::FromInt(flags)); |
CallRuntimeFromDeferred( |
- Runtime::kHiddenAllocateInTargetSpace, 2, instr, instr->context()); |
+ Runtime::kAllocateInTargetSpace, 2, instr, instr->context()); |
__ StoreToSafepointRegisterSlot(result, rax); |
} |
@@ -5381,7 +5381,7 @@ void LCodeGen::DoRegExpLiteral(LRegExpLiteral* instr) { |
__ Push(Smi::FromInt(instr->hydrogen()->literal_index())); |
__ Push(instr->hydrogen()->pattern()); |
__ Push(instr->hydrogen()->flags()); |
- CallRuntime(Runtime::kHiddenMaterializeRegExpLiteral, 4, instr); |
+ CallRuntime(Runtime::kMaterializeRegExpLiteral, 4, instr); |
__ movp(rbx, rax); |
__ bind(&materialized); |
@@ -5393,7 +5393,7 @@ void LCodeGen::DoRegExpLiteral(LRegExpLiteral* instr) { |
__ bind(&runtime_allocate); |
__ Push(rbx); |
__ Push(Smi::FromInt(size)); |
- CallRuntime(Runtime::kHiddenAllocateInNewSpace, 1, instr); |
+ CallRuntime(Runtime::kAllocateInNewSpace, 1, instr); |
__ Pop(rbx); |
__ bind(&allocated); |
@@ -5428,7 +5428,7 @@ void LCodeGen::DoFunctionLiteral(LFunctionLiteral* instr) { |
__ Push(instr->hydrogen()->shared_info()); |
__ PushRoot(pretenure ? Heap::kTrueValueRootIndex : |
Heap::kFalseValueRootIndex); |
- CallRuntime(Runtime::kHiddenNewClosure, 3, instr); |
+ CallRuntime(Runtime::kNewClosure, 3, instr); |
} |
} |
@@ -5625,7 +5625,7 @@ void LCodeGen::DoDummyUse(LDummyUse* instr) { |
void LCodeGen::DoDeferredStackCheck(LStackCheck* instr) { |
PushSafepointRegistersScope scope(this); |
__ movp(rsi, Operand(rbp, StandardFrameConstants::kContextOffset)); |
- __ CallRuntimeSaveDoubles(Runtime::kHiddenStackGuard); |
+ __ CallRuntimeSaveDoubles(Runtime::kStackGuard); |
RecordSafepointWithLazyDeopt(instr, RECORD_SAFEPOINT_WITH_REGISTERS, 0); |
ASSERT(instr->HasEnvironment()); |
LEnvironment* env = instr->environment(); |
@@ -5840,7 +5840,7 @@ void LCodeGen::DoAllocateBlockContext(LAllocateBlockContext* instr) { |
Handle<ScopeInfo> scope_info = instr->scope_info(); |
__ Push(scope_info); |
__ Push(ToRegister(instr->function())); |
- CallRuntime(Runtime::kHiddenPushBlockContext, 2, instr); |
+ CallRuntime(Runtime::kPushBlockContext, 2, instr); |
RecordSafepoint(Safepoint::kNoLazyDeopt); |
} |
@@ -4731,11 +4731,11 @@ void LCodeGen::DoDeferredNumberTagIU(LInstruction* instr, |
// NumberTagIU uses the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
- // They only call Runtime::kHiddenAllocateHeapNumber. |
+ // They only call Runtime::kAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
@@ -4787,11 +4787,11 @@ void LCodeGen::DoDeferredNumberTagD(LNumberTagD* instr) { |
// NumberTagD uses the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
- // They only call Runtime::kHiddenAllocateHeapNumber. |
+ // They only call Runtime::kAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |